CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                            Pio (Fortran)                            C
C                                                                     C
C                    Polyglot Input/Output Library                    C
C                                                                     C
C                  projet Estime, INRIA-Rocquencourt                  C
C                                                                     C
C  Copyright 2004-2011 INRIA.                                         C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C $Id: send_communication.F,v 1.4 2011-03-09 12:50:16 fclement Exp $

C     
C     PIOs send API.
C
C     Routines for the programmer to send a communication.
C     
      
#include "pio_constants.h"
      
      subroutine pio_init_out_communication(tc, nv)
C     Initialize a new outgoing communication of type tc with nv values.
      
      implicit none
      
C     Input arguments.
      integer tc, nv
      
C     Local variables.
      character sbr*28, stc*MAX_STRING_LENGTH
      integer len, svn, svd_ptr, bc
      
C     External functions.
      logical pio_get_debug_mode
      integer get_store_value_number, get_store_ptr
      
      sbr = 'pio_init_send_communication'
      
      if (pio_get_debug_mode()) then
         call string_of_communication_type(sbr, tc, len, stc)
         write(PIO_DEBUG, *)
     +        'Initializing the outgoing communication ',
     +        'for a ', stc(1:len), ' communication of ', nv,
     +        ' values.'
      endif
      
      call init_memory(sbr, PIO_OUT)
      call init_memory_mapping(sbr, PIO_OUT)
      
      call store_communication_type(sbr, PIO_OUT, tc)
      call store_communication_values_number(sbr, PIO_OUT, nv)
      
      svn = get_store_value_number(PIO_OUT)
      svd_ptr = SLOT_VALUE_DESCRIPTOR_ADDRESSES + nv + 1
      call set_store_value_descriptor_ptr(sbr, PIO_OUT, svd_ptr)
      call store_communication_value_descriptor_address
     +     (sbr, PIO_OUT, svn, svd_ptr)
      call advance_store_value_descriptor_ptr
     +     (sbr, PIO_OUT, SLOT_VALUE_SIZES_BEGIN)
      
      bc = get_store_ptr(PIO_OUT)
      call store_communication_begin(sbr, PIO_OUT, bc)
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *)
     +        'The outgoing communication is initialized ',
     +        'for a ', stc(1:len), ' communication of ', nv,
     +        ' values.'
      endif
      
      return
      end
      
      
      subroutine commit_print_communication
C     The outgoing communication in memory is ready for printing.
      
      implicit none
      
C     Local variables.
      character sbr*27
      integer ec, good, bad
      
C     External functions.
      logical pio_get_debug_mode, pio_get_report_mode
      integer get_store_ptr, fetch_communication_values_number
      integer get_store_value_number
      
      sbr = 'commit_print_communication'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *)
     +        'Commiting the outgoing communication'
      endif
      
      ec = get_store_ptr(PIO_OUT)
      call store_communication_end(sbr, PIO_OUT, ec)
      
C     Check that the correct number of values has been written.
      call set_memory_mapping_clean(PIO_OUT, .True.)
      good = fetch_communication_values_number(sbr, PIO_OUT)
      bad = get_store_value_number(PIO_OUT) - 1
      
      if (bad .ne. good) then
         call pio_error_wrong_number_of_values(sbr, PIO_OUT, good, bad)
      endif
      
      call set_memory_clean(PIO_OUT, .True.)
      
      if (pio_get_report_mode()) then
         
         write(PIO_REPORT, *) ' '
         call pio_write_memory_mapping(PIO_OUT)
         write(PIO_REPORT, *) ' '
         
         write(PIO_REPORT, *) ' '
         call pio_write_memory(PIO_OUT)
         write(PIO_REPORT, *) ' '
      
      endif
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *)
     +        'The outgoing communication has been committed'
      endif
      
      return
      end
      
      
      subroutine pio_send_out_communication(oc)
C     Send a communication on output channel oc.
      
      implicit none
      
C     Input argument.
      integer oc
      
      call commit_print_communication
      call print_communication(oc)
      
      return
      end
      
      
      subroutine pio_add_communication_name(len, name)
C     Add its name to a task, or a service, communication.
      
      implicit none
      
C     Input arguments.
      character name*(*)
      integer len
      
C     Local variable.
      character sbr*26
      
      sbr = 'pio_add_communication_name'
      
      call seq_store_communication_name(sbr, PIO_OUT, name, len)
      
      return
      end
      
      
      subroutine add_fixed_slots(sbr, tv, pv)
C     Beginning of value addition to the communication.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer tv, pv
      
C     Local variable.
      integer bv
      
C     External function.
      integer get_store_ptr
      
      bv = get_store_ptr(PIO_OUT)
      
      call store_value_begin(sbr, PIO_OUT, bv)
      call store_value_type(sbr, PIO_OUT, tv)
      call store_value_dimension(sbr, PIO_OUT, pv)
      
      return
      end
      
      
      subroutine add_scalar_value_begin(sbr, tv)
C     Ending of value addition to the communication.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer tv
      
C     Local variable.
      integer pv
      
      pv = SCALAR_DIMENSION
      
      call add_fixed_slots(sbr, tv, pv)
      
      return
      end
      
      
      subroutine add_vector_value_begin(sbr, tv, n)
C     Ending of vector value addition to the communication.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer tv, n
      
C     Local variable.
      integer pv
      
      pv = VECTOR_DIMENSION
      
      call add_fixed_slots(sbr, tv, pv)
      
      call store_value_size(sbr, PIO_OUT, pv, n)
      
      return
      end
      
      
      subroutine add_matrix_value_begin(sbr, tv, ni, nj, lkv)
C     Ending of vector value addition to the communication.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer tv, ni, nj, lkv
      
C     Local variables.
      integer pv, sizev(2)
      
      pv = MULTI_D_DIMENSION(2)
      
      call add_fixed_slots(sbr, tv, pv)
      
      sizev(1) = ni
      sizev(2) = nj
      
      call store_value_size(sbr, PIO_OUT, pv, sizev)
      call store_value_layout_kind(sbr, PIO_OUT, lkv)
      
      return
      end
      
      
      subroutine add_value_end(sbr)
C     Ending of value addition to the communication and be prepared for
C     the next value.
      
      implicit none
      
C     Input argument.
      character sbr*(*)
      
C     Local variable.
      integer ev
      
C     External function.
      integer get_store_ptr
      
      ev = get_store_ptr(PIO_OUT)
      
      call store_value_end(sbr, PIO_OUT, ev)
      
      call next_value_next_value_descriptor(sbr, PIO_OUT)
      
      return
      end
      
      
      subroutine pio_add_string(len, sdatum)
C     Add to the communication the string value sdatum of length len.
      
      implicit none
      
C     Input arguments.
      character sdatum*(*)
      integer len
      
C     Local variable.
      character sbr*14
      
      sbr = 'pio_add_string'
      
      call add_scalar_value_begin(sbr, SSTRING)
      call seq_store_string_value(sbr, PIO_OUT, sdatum, len)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_int(idatum)
C     Add to the communication the integer value idatum.
      
      implicit none
      
C     Input argument.
      integer idatum
      
C     Local variable.
      character sbr*11
      
      sbr = 'pio_add_int'
      
      call add_scalar_value_begin(sbr, SINT)
      call seq_store_int_value(sbr, PIO_OUT, idatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_float(fdatum)
C     Add to the communication the float value fdatum.
      
      implicit none
      
C     Input argument.
      FLOAT fdatum
      
C     Local variable.
      character sbr*13
      
      sbr = 'pio_add_float'
      
      call add_scalar_value_begin(sbr, SFLOAT)
      call seq_store_float_value(sbr, PIO_OUT, fdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_string_couple(len1, s1, len2, s2)
C     Add to the communication the string couple (s1, s2) of lengths
C     (len1, len2).
      
      implicit none
      
C     Input arguments.
      character s1*(*), s2*(*)
      integer len1, len2
      
C     Local variables.
      character sbr*21, svdatum(2)*(MAX_STRING_LENGTH)
      integer vlen(2)
      
      sbr = 'pio_add_string_triple'
      
      vlen(1) = len1
      vlen(2) = len2
      svdatum(1)(1:len1) = s1(1:len1)
      svdatum(2)(1:len2) = s2(1:len2)
      
      call add_scalar_value_begin
     +     (sbr, MAKE_COUPLE_TYPE(SSTRING))
      
      call seq_store_string_compound_value
     +     (sbr, PIO_OUT, 2, vlen, svdatum)
      call add_value_end(sbr)
      return
      end
      
      
      subroutine pio_add_int_couple(i1, i2)
C     Add to the communication the integer couple (i1, i2).
      
      implicit none
      
C     Input arguments.
      integer i1, i2
      
C     Local variable.
      character sbr*18
      integer icdatum(2)
      
      sbr = 'pio_add_int_couple'
      
      icdatum(1) = i1
      icdatum(2) = i2
      
      call add_scalar_value_begin
     +     (sbr, MAKE_COUPLE_TYPE(SINT))
      call seq_store_int_compound_value(sbr, PIO_OUT, 2, icdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_float_couple(f1, f2)
C     Add to the communication the float couple (f1, f2).
      
      implicit none
      
C     Input arguments.
      FLOAT f1, f2
      
C     Local variable.
      character sbr*20
      FLOAT fcdatum(2)
      
      sbr = 'pio_add_float_couple'
      
      fcdatum(1) = f1
      fcdatum(2) = f2
      
      call add_scalar_value_begin
     +     (sbr, MAKE_COUPLE_TYPE(SFLOAT))
      call seq_store_float_compound_value(sbr, PIO_OUT, 2, fcdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_string_triple(len1, s1, len2, s2, len3, s3)
C     Add to the communication the string triple (s1, s2, s3) of lengths
C     (len1, len2, len3).
      
      implicit none
      
C     Input arguments.
      character s1*(*), s2*(*), s3*(*)
      integer len1, len2, len3
      
C     Local variables.
      character sbr*21, svdatum(3)*(MAX_STRING_LENGTH)
      integer vlen(3)
      
      sbr = 'pio_add_string_triple'
      
      vlen(1) = len1
      vlen(2) = len2
      vlen(3) = len3
      svdatum(1)(1:len1) = s1(1:len1)
      svdatum(2)(1:len2) = s2(1:len2)
      svdatum(3)(1:len3) = s3(1:len3)
      
      call add_scalar_value_begin
     +     (sbr, MAKE_TRIPLE_TYPE(SSTRING))
      call seq_store_string_compound_value
     +     (sbr, PIO_OUT, 3, vlen, svdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_int_triple(i1, i2, i3)
C     Add to the communication the integer triple (i1, i2, i3).
      
      implicit none
      
C     Input arguments.
      integer i1, i2, i3
      
C     Local variable.
      character sbr*18
      integer itdatum(3)
      
      sbr = 'pio_add_int_triple'
      
      itdatum(1) = i1
      itdatum(2) = i2
      itdatum(3) = i3
      
      call add_scalar_value_begin
     +     (sbr, MAKE_TRIPLE_TYPE(SINT))
      call seq_store_int_compound_value(sbr, PIO_OUT, 3, itdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_float_triple(f1, f2, f3)
C     Add to the communication the float triple (f1, f2, f3).
      
      implicit none
      
C     Input arguments.
      FLOAT f1, f2, f3
      
C     Local variable.
      character sbr*20
      FLOAT ftdatum(3)
      
      sbr = 'pio_add_float_triple'
      
      ftdatum(1) = f1
      ftdatum(2) = f2
      ftdatum(3) = f3
      
      call add_scalar_value_begin
     +     (sbr, MAKE_TRIPLE_TYPE(SFLOAT))
      call seq_store_float_compound_value(sbr, PIO_OUT, 3, ftdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_string_vector(n, vlen, svdatum)
C     Add to the communication the string vector svdatum of dimension n
C     and of lengths vlen.
      
      implicit none
      
C     Input arguments.
      character svdatum*(*)
      integer n, vlen(*)
      
C     Local variables.
      character sbr*21
      
      sbr = 'pio_add_string_vector'
      
      call add_vector_value_begin
     +     (sbr, MAKE_VECTOR_TYPE(SSTRING), n)
      call seq_store_string_compound_value
     +     (sbr, PIO_OUT, n, vlen, svdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_int_vector(n, ivdatum)
C     Add to the communication the int vector value ivdatum of size n.
      
      implicit none
      
C     Input arguments.
      integer n, ivdatum(*)
      
C     Local variable.
      character sbr*18
      
      sbr = 'pio_add_int_vector'
      
      call add_vector_value_begin
     +     (sbr, MAKE_VECTOR_TYPE(SINT), n)
      call seq_store_int_compound_value(sbr, PIO_OUT, n, ivdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_float_vector(n, fvdatum)
C     Add to the communication the float vector value fvdatum of size n.
      
      implicit none
      
C     Input arguments.
      integer n
      FLOAT fvdatum(*)
      
C     Local variable.
      character sbr*20
      
      sbr = 'pio_add_float_vector'
      
      call add_vector_value_begin
     +     (sbr, MAKE_VECTOR_TYPE(SFLOAT), n)
      call seq_store_float_compound_value(sbr, PIO_OUT, n, fvdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_int_couple_vector(n, icvdatum)
C     Add to the communication the int couple vector value icvdatum of
C     size n.
      
      implicit none
      
C     Input arguments.
      integer n, icvdatum(2, *)
      
C     Local variable.
      character sbr*25
      
      sbr = 'pio_add_int_couple_vector'
      
      call add_vector_value_begin
     +     (sbr, 
     +     MAKE_VECTOR_COUPLE_TYPE(SINT),
     +     n)
      call seq_store_int_compound_value(sbr, PIO_OUT, 2*n, icvdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_float_couple_vector(n, fcvdatum)
C     Add to the communication the float couple vector value fcvdatum of
C     size n.
      
      implicit none
      
C     Input arguments.
      integer n
      FLOAT fcvdatum(2, *)
      
C     Local variable.
      character sbr*27
      
      sbr = 'pio_add_float_couple_vector'
      
      call add_vector_value_begin
     +     (sbr,
     +     MAKE_VECTOR_COUPLE_TYPE(SFLOAT),
     +     n)
      call seq_store_float_compound_value(sbr, PIO_OUT, 2*n, fcvdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_int_triple_vector(n, itvdatum)
C     Add to the communication the int triple vector value itvdatum of
C     size n.
      
      implicit none
      
C     Input arguments.
      integer n, itvdatum(3, *)
      
C     Local variable.
      character sbr*25
      
      sbr = 'pio_add_int_triple_vector'
      
      call add_vector_value_begin
     +     (sbr,
     +     MAKE_VECTOR_TRIPLE_TYPE(SINT),
     +     n)
      call seq_store_int_compound_value(sbr, PIO_OUT, 3*n, itvdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_float_triple_vector(n, ftvdatum)
C     Add to the communication the float triple vector value ftvdatum of
C     size n.
      
      implicit none
      
C     Input arguments.
      integer n
      FLOAT ftvdatum(3, *)
      
C     Local variable.
      character sbr*27
      
      sbr = 'pio_add_float_triple_vector'
      
      call add_vector_value_begin
     +     (sbr,
     +     MAKE_VECTOR_TRIPLE_TYPE(SFLOAT),
     +     n)
      call seq_store_float_compound_value(sbr, PIO_OUT, 3*n, ftvdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_fortran_float_matrix(ni, nj, fmdatum)
C     Add to the communication the float matrix value fmdatum of size
C     ni x nj as a Fortran matrix (ie, by columns).
      
      implicit none
      
C     Input arguments.
      integer ni, nj
      FLOAT fmdatum(ni, nj)
      
C     Local variable.
      character sbr*28
      
      sbr = 'pio_add_fortran_float_matrix'
      
      call add_matrix_value_begin
     +     (sbr,
     +     MAKE_MULTI_D_TYPE(SFLOAT),
     +     ni, nj, FORTRAN_LAYOUT_KIND)
      call seq_store_float_compound_value(sbr, PIO_OUT, ni*nj, fmdatum)
      call add_value_end(sbr)
      
      return
      end
      
      
      subroutine pio_add_c_float_matrix(ni, nj, fmdatum)
C     Add to the communication the float matrix value fmdatum of size
C     ni x nj as a C matrix (ie, by rows).
      
      implicit none
      
C     Input arguments.
      integer ni, nj
      FLOAT fmdatum(ni, nj), tfmdatum(nj, ni)
      
C     Local variables.
      character sbr*22
      integer i, j
      
      sbr = 'pio_add_c_float_matrix'
      
      do j = 1, nj
         do i = 1, ni
            tfmdatum(j, i) = fmdatum(i, j)
         enddo
      enddo
      
      call add_matrix_value_begin
     +     (sbr,
     +     MAKE_MULTI_D_TYPE(SFLOAT),
     +     ni, nj, C_LAYOUT_KIND)
      call seq_store_float_compound_value(sbr, PIO_OUT, nj*ni, tfmdatum)
      call add_value_end(sbr)
      
      return
      end
